@@ -1,8 +1,6 @@
 package detector
 
 import (
-	log "github.com/sirupsen/logrus"
-	"github.com/cheggaaa/pb/v3"
 	"os"
 	"talisman/checksumcalculator"
 	"talisman/detector/detector"
@@ -13,28 +11,31 @@ import (
 	"talisman/gitrepo"
 	"talisman/talismanrc"
 	"talisman/utility"
+
+	log "github.com/sirupsen/logrus"
 )
 
 //Chain represents a chain of Detectors.
 //It is itself a detector.
 type Chain struct {
 	detectors []detector.Detector
+	mode      string
 }
 
 //NewChain returns an empty DetectorChain
 //It is itself a detector, but it tests nothing.
-func NewChain() *Chain {
-	result := Chain{make([]detector.Detector, 0)}
+func NewChain(hooktype string) *Chain {
+	result := Chain{[]detector.Detector{}, hooktype}
 	return &result
 }
 
 //DefaultChain returns a DetectorChain with pre-configured detectors
-func DefaultChain(tRC *talismanrc.TalismanRC) *Chain {
-	result := NewChain()
-	result.AddDetector(filename.DefaultFileNameDetector(tRC.Threshold))
-	result.AddDetector(filecontent.NewFileContentDetector(tRC))
-	result.AddDetector(pattern.NewPatternDetector(tRC.CustomPatterns))
-	return result
+func DefaultChain(tRC *talismanrc.TalismanRC, runMode string) *Chain {
+	chain := NewChain(runMode)
+	chain.AddDetector(filename.DefaultFileNameDetector(tRC.Threshold))
+	chain.AddDetector(filecontent.NewFileContentDetector(tRC))
+	chain.AddDetector(pattern.NewPatternDetector(tRC.CustomPatterns))
+	return chain
 }
 
 //AddDetector adds the detector that is passed in to the chain
@@ -49,13 +50,13 @@ func (dc *Chain) Test(currentAdditions []gitrepo.Addition, talismanRC *talismanr
 	wd, _ := os.Getwd()
 	repo := gitrepo.RepoLocatedAt(wd)
 	allAdditions := repo.TrackedFilesAsAdditions()
-	hasher := utility.DefaultSHA256Hasher{}
+	hasher := utility.MakeHasher(dc.mode, wd)
 	calculator := checksumcalculator.NewChecksumCalculator(hasher, append(allAdditions, currentAdditions...))
 	cc := helpers.NewChecksumCompare(calculator, hasher, talismanRC)
 	log.Printf("Number of files to scan: %d\n", len(currentAdditions))
 	log.Printf("Number of detectors: %d\n", len(dc.detectors))
 	total := len(currentAdditions) * len(dc.detectors)
-	var progressBar = getProgressBar()
+	progressBar := utility.GetProgressBar(os.Stdout, "Talisman Scan")
 	progressBar.Start(total)
 	for _, v := range dc.detectors {
 		v.Test(cc, currentAdditions, talismanRC, result, func() {
@@ -64,49 +65,3 @@ func (dc *Chain) Test(currentAdditions []gitrepo.Addition, talismanRC *talismanr
 	}
 	progressBar.Finish()
 }
-
-func getProgressBar() progressBar {
-	if isTerminal() {
-		return &defaultProgressBar{}
-	} else {
-		return &noOpProgressBar{}
-	}
-}
-
-func isTerminal() bool {
-	fileInfo, _ := os.Stdout.Stat()
-	return (fileInfo.Mode() & os.ModeCharDevice) != 0
-}
-
-type progressBar interface {
-	Start(int)
-	Increment()
-	Finish()
-}
-
-type noOpProgressBar struct {
-}
-
-func (d *noOpProgressBar) Start(int) {}
-
-func (d *noOpProgressBar) Increment() {}
-
-func (d *noOpProgressBar) Finish() {}
-
-type defaultProgressBar struct {
-	bar *pb.ProgressBar
-}
-
-func (d *defaultProgressBar) Start(total int) {
-	bar := pb.ProgressBarTemplate(`{{ red "Talisman Scan:" }} {{counters .}} {{ bar . "<" "-" (cycle . "↖" "↗" "↘" "↙" ) "." ">"}} {{percent . | rndcolor }} {{green}} {{blue}}`).New(total)
-	bar.Set(pb.Terminal, true)
-	d.bar = bar.Start()
-}
-
-func (d *defaultProgressBar) Increment() {
-	d.bar.Increment()
-}
-
-func (d *defaultProgressBar) Finish() {
-	d.bar.Finish()
-}
