@@ -13,12 +13,13 @@ import (
 )
 
 var talismanRC = &talismanrc.TalismanRC{}
+var defaultHasher = utility.MakeHasher("default", ".")
 
 func TestShouldFlagLargeFiles(t *testing.T) {
 	results := helpers.NewDetectionResults(talismanrc.HookMode)
 	content := []byte("more than one byte")
 	additions := []gitrepo.Addition{gitrepo.NewAddition("filename", content)}
-	NewFileSizeDetector(2).Test(helpers.NewChecksumCompare(nil, utility.DefaultSHA256Hasher{}, &talismanrc.TalismanRC{}), additions, talismanRC, results, func() {})
+	NewFileSizeDetector(2).Test(helpers.NewChecksumCompare(nil, defaultHasher, talismanRC), additions, talismanRC, results, func() {})
 	assert.True(t, results.HasFailures(), "Expected file to fail the check against file size detector.")
 }
 
@@ -27,7 +28,7 @@ func TestShouldNotFlagLargeFilesIfThresholdIsBelowSeverity(t *testing.T) {
 	content := []byte("more than one byte")
 	talismanRCWithThreshold := &talismanrc.TalismanRC{Threshold: severity.High}
 	additions := []gitrepo.Addition{gitrepo.NewAddition("filename", content)}
-	NewFileSizeDetector(2).Test(helpers.NewChecksumCompare(nil, utility.DefaultSHA256Hasher{}, talismanRCWithThreshold), additions, talismanRCWithThreshold, results, func() {})
+	NewFileSizeDetector(2).Test(helpers.NewChecksumCompare(nil, defaultHasher, talismanRCWithThreshold), additions, talismanRCWithThreshold, results, func() {})
 	assert.False(t, results.HasFailures(), "Expected file to not to fail the check against file size detector.")
 	assert.True(t, results.HasWarnings(), "Expected file to have warnings against file size detector.")
 }
@@ -36,7 +37,7 @@ func TestShouldNotFlagSmallFiles(t *testing.T) {
 	results := helpers.NewDetectionResults(talismanrc.HookMode)
 	content := []byte("m")
 	additions := []gitrepo.Addition{gitrepo.NewAddition("filename", content)}
-	NewFileSizeDetector(2).Test(helpers.NewChecksumCompare(nil, utility.DefaultSHA256Hasher{}, &talismanrc.TalismanRC{}), additions, talismanRC, results, func() {})
+	NewFileSizeDetector(2).Test(helpers.NewChecksumCompare(nil, defaultHasher, talismanRC), additions, talismanRC, results, func() {})
 	assert.False(t, results.HasFailures(), "Expected file to not to fail the check against file size detector.")
 }
 
@@ -54,6 +55,6 @@ func TestShouldNotFlagIgnoredLargeFiles(t *testing.T) {
 	talismanRC.IgnoreConfigs[0] = fileIgnoreConfig
 
 	additions := []gitrepo.Addition{gitrepo.NewAddition(filename, content)}
-	NewFileSizeDetector(2).Test(helpers.NewChecksumCompare(nil, utility.DefaultSHA256Hasher{}, talismanRC), additions, talismanRC, results, func() {})
+	NewFileSizeDetector(2).Test(helpers.NewChecksumCompare(nil, defaultHasher, talismanRC), additions, talismanRC, results, func() {})
 	assert.True(t, results.Successful(), "expected file %s to be ignored by file size detector", filename)
 }
