@@ -55,44 +55,6 @@ type DetectionResults struct {
 	Results []ResultsDetails `json:"results"`
 }
 
-func (r *ResultsDetails) getWarningDataByCategoryAndMessage(failureMessage string, category string) *Details {
-	detail := getDetailsByCategoryAndMessage(r.WarningList, category, failureMessage)
-	r.WarningList = append(r.WarningList, *detail)
-	return detail
-}
-
-func (r *ResultsDetails) getFailureDataByCategoryAndMessage(failureMessage string, category string) *Details {
-	detail := getDetailsByCategoryAndMessage(r.FailureList, category, failureMessage)
-	if detail == nil {
-		detail = &Details{category, failureMessage, make([]string, 0), severity.Low}
-		r.FailureList = append(r.FailureList, *detail)
-	}
-	return detail
-}
-
-func (r *ResultsDetails) addIgnoreDataByCategory(category string) {
-	isCategoryAlreadyPresent := false
-	for _, detail := range r.IgnoreList {
-		if strings.Compare(detail.Category, category) == 0 {
-			isCategoryAlreadyPresent = true
-		}
-	}
-	if !isCategoryAlreadyPresent {
-		detail := Details{category, "", make([]string, 0), severity.Low}
-		r.IgnoreList = append(r.IgnoreList, detail)
-	}
-}
-
-func getDetailsByCategoryAndMessage(detailsList []Details, category string, failureMessage string) *Details {
-	for _, detail := range detailsList {
-		if strings.Compare(detail.Category, category) == 0 && strings.Compare(detail.Message, failureMessage) == 0 {
-			return &detail
-		}
-	}
-
-	return nil
-}
-
 func (r *DetectionResults) getResultDetailsForFilePath(fileName gitrepo.FilePath) *ResultsDetails {
 	for _, resultDetail := range r.Results {
 		if resultDetail.Filename == fileName {
@@ -140,7 +102,7 @@ func (r *DetectionResults) Fail(filePath gitrepo.FilePath, category string, mess
 		resultDetails.FailureList = append(resultDetails.FailureList, failureDetails)
 		r.Results = append(r.Results, resultDetails)
 	}
-	r.updateResultsSummary(category)
+	r.updateResultsSummary(category, false)
 }
 
 func (r *DetectionResults) Warn(filePath gitrepo.FilePath, category string, message string, commits []string, severity severity.Severity) {
@@ -199,14 +161,18 @@ func (r *DetectionResults) Ignore(filePath gitrepo.FilePath, category string) {
 	r.Summary.Types.Ignores++
 }
 
-func (r *DetectionResults) updateResultsSummary(category string) {
+func (r *DetectionResults) updateResultsSummary(category string, decr bool) {
+	val := 1
+	if decr {
+		val = -1
+	}
 	switch category {
 	case "filecontent":
-		r.Summary.Types.Filecontent++
+		r.Summary.Types.Filecontent += val
 	case "filename":
-		r.Summary.Types.Filename++
+		r.Summary.Types.Filename += val
 	case "filesize":
-		r.Summary.Types.Filesize++
+		r.Summary.Types.Filesize += val
 	}
 }
 
@@ -243,8 +209,6 @@ func (r *DetectionResults) GetFailures(fileName gitrepo.FilePath) []Details {
 }
 
 func (r *DetectionResults) ReportWarnings() string {
-	var result string
-	var filePathsForWarnings []string
 	var data [][]string
 
 	table := tablewriter.NewWriter(os.Stdout)
@@ -253,27 +217,25 @@ func (r *DetectionResults) ReportWarnings() string {
 
 	for _, resultDetails := range r.Results {
 		if len(resultDetails.WarningList) > 0 {
-			filePathsForWarnings = append(filePathsForWarnings, string(resultDetails.Filename))
 			warningData := r.ReportFileWarnings(resultDetails.Filename)
 			data = append(data, warningData...)
 		}
 	}
 
-	filePathsForWarnings = utility.UniqueItems(filePathsForWarnings)
+	results := strings.Builder{}
 	if r.Summary.Types.Warnings > 0 {
 		fmt.Printf("\n\x1b[1m\x1b[31mTalisman Warnings:\x1b[0m\x1b[0m\n")
 		table.AppendBulk(data)
 		table.Render()
-		result = result + fmt.Sprintf("\n\x1b[33mPlease review the above file(s) to make sure that no sensitive content is being pushed\x1b[0m\n")
-		result = result + fmt.Sprintf("\n")
+		results.WriteString("\n\x1b[33mPlease review the above file(s) to make sure that no sensitive content is being pushed\x1b[0m\n\n")
 	}
-	return result
+	return results.String()
 }
 
 //Report returns a string documenting the various failures and ignored files for the current run
-func (r *DetectionResults) Report(promptContext prompt.PromptContext) string {
+func (r *DetectionResults) Report(promptContext prompt.PromptContext, mode string) string {
 	var result string
-	var filePathsForIgnoresAndFailures []string
+	var filePathsForFailures []string
 	var data [][]string
 
 	table := tablewriter.NewWriter(os.Stdout)
@@ -281,30 +243,30 @@ func (r *DetectionResults) Report(promptContext prompt.PromptContext) string {
 	table.SetRowLine(true)
 
 	for _, resultDetails := range r.Results {
-		if len(resultDetails.FailureList) > 0 || len(resultDetails.IgnoreList) > 0 {
-			filePathsForIgnoresAndFailures = append(filePathsForIgnoresAndFailures, string(resultDetails.Filename))
+		if len(resultDetails.FailureList) > 0 {
+			filePathsForFailures = append(filePathsForFailures, string(resultDetails.Filename))
 			failureData := r.ReportFileFailures(resultDetails.Filename)
 			data = append(data, failureData...)
 		}
 	}
 
-	filePathsForIgnoresAndFailures = utility.UniqueItems(filePathsForIgnoresAndFailures)
+	filePathsForFailures = utility.UniqueItems(filePathsForFailures)
 
 	if r.HasFailures() {
 		fmt.Printf("\n\x1b[1m\x1b[31mTalisman Report:\x1b[0m\x1b[0m\n")
 		table.AppendBulk(data)
 		table.Render()
 		fmt.Println()
-		r.suggestTalismanRC(filePathsForIgnoresAndFailures, promptContext)
+		r.suggestTalismanRC(filePathsForFailures, promptContext, mode)
 	}
 	return result
 }
 
-func (r *DetectionResults) suggestTalismanRC(filePaths []string, promptContext prompt.PromptContext) {
+func (r *DetectionResults) suggestTalismanRC(filePaths []string, promptContext prompt.PromptContext, mode string) {
 	var entriesToAdd []talismanrc.IgnoreConfig
-
+	hasher := utility.MakeHasher(mode, ".")
 	for _, filePath := range filePaths {
-		currentChecksum := utility.DefaultSHA256Hasher{}.CollectiveSHA256Hash([]string{filePath})
+		currentChecksum := hasher.CollectiveSHA256Hash([]string{filePath})
 		fileIgnoreConfig := talismanrc.BuildIgnoreConfig(r.mode, filePath, currentChecksum, []string{})
 		entriesToAdd = append(entriesToAdd, fileIgnoreConfig)
 	}
@@ -312,6 +274,14 @@ func (r *DetectionResults) suggestTalismanRC(filePaths []string, promptContext p
 	if promptContext.Interactive && runtime.GOOS != "windows" {
 		confirmedEntries := getUserConfirmation(entriesToAdd, promptContext)
 		talismanrc.ConfigFromFile().AddIgnores(r.mode, confirmedEntries)
+
+		for _, confirmedEntry := range confirmedEntries {
+			resultsDetails := r.getResultDetailsForFilePath(gitrepo.FilePath(confirmedEntry.GetFileName()))
+			for _, failure := range resultsDetails.FailureList {
+				r.updateResultsSummary(failure.Category, true)
+			}
+		}
+
 		output, err := exec.Command("git", "add", ".talismanrc").CombinedOutput()
 		if err != nil {
 			logrus.Errorf("Error appending to talismanrc %v", output)
