@@ -5,6 +5,10 @@ import (
 	"os/exec"
 	"strings"
 	"talisman/gitrepo"
+	"talisman/utility"
+	"os"
+
+	"github.com/sirupsen/logrus"
 )
 
 type blobDetails struct {
@@ -17,26 +21,43 @@ type BlobsInCommits struct {
 }
 
 // GetAdditions will get all the additions for entire git history
-func GetAdditions(ignoreHistory bool) []gitrepo.Addition {
+func GetAdditions(ignoreHistory bool, br gitrepo.BatchReader) []gitrepo.Addition {
 	blobsInCommits := getBlobsInCommit(ignoreHistory)
 	var additions []gitrepo.Addition
+	err := br.Start()
+	if err != nil {
+		logrus.Errorf("error creating file reader %v", err)
+	}
+	defer func() {
+		err = br.Shutdown()
+		if err != nil {
+			logrus.Errorf("error creating file reader %v", err)
+		}
+	}()
+
 	for blob := range blobsInCommits.commits {
-		newAddition := gitrepo.NewScannerAddition(blob.filePath, blobsInCommits.commits[blob], getData(blob.hash))
+		contents, _ := br.Read(blob.hash)
+		newAddition := gitrepo.NewScannerAddition(blob.filePath, blobsInCommits.commits[blob], contents)
 		additions = append(additions, newAddition)
 	}
+
 	return additions
 }
 
 func getBlobsInCommit(ignoreHistory bool) BlobsInCommits {
+	progressBar := utility.GetProgressBar(os.Stdout, "Talisman Fetch Blobs")
 	commits := getAllCommits(ignoreHistory)
+	progressBar.Start(len(commits) - 1)
 	blobsInCommits := newBlobsInCommit()
 	result := make(chan []string, len(commits))
 	for _, commit := range commits {
 		go putBlobsInChannel(commit, result)
 	}
 	for i := 1; i < len(commits); i++ {
+		progressBar.Increment()
 		getBlobsFromChannel(blobsInCommits, result)
 	}
+	progressBar.Finish()
 	return blobsInCommits
 }
 
@@ -73,11 +94,6 @@ func getAllCommits(ignoreHistory bool) []string {
 	return strings.Split(string(out), "\n")
 }
 
-func getData(objectHash string) []byte {
-	out, _ := exec.Command("git", "cat-file", "-p", objectHash).CombinedOutput()
-	return out
-}
-
 func newBlobsInCommit() BlobsInCommits {
 	commits := make(map[blobDetails][]string)
 	return BlobsInCommits{commits: commits}
